==> spip_2.1.orig.tar.gz: spip-2.1.orig/extensions/porte_plume/lang/barre_outils_en.php <==
<?php
$GLOBALS[$GLOBALS['idx_lang']] = array(

// B Nouveautes 
'barre_clean' => 'Clean the code of all HTML tags',
'barre_lorem_ipsum' => 'Insert a fake paragraph',
'barre_lorem_ipsum_3' => 'Insert three fake paragraphs',
'barre_liste_ul' => 'Set list',
'barre_liste_ol' => 'Set numbered list',
'barre_indenter' => 'Indent a line',
'barre_desindenter' => 'Unindent a line',
'barre_inserer_caracteres' => 'Insert special characters',
'barre_barre' => 'Strike through the text',

'editer'=>'Edit',
'voir'=>'Preview',


// B (depuis SPIP)
'barre_a_accent_grave' => 'Insert a capital A with grave accent: &Agrave;',
'barre_aide' => 'Use the typographic short cuts to refine your layout',
'barre_c_cedille_maj' => 'Insert a capital &Ccedil; with cedilla: &Ccedil;',
'barre_e_accent_aigu' => 'Insert a capital E with acute accent: &Eacute;',
'barre_e_accent_grave' => 'Insert a capital E with grave accent: &Egrave;',
'barre_ea' => 'Insert an oe-ligature: &aelig;',
'barre_ea_maj' => 'Insert a capital an oe-ligature: &AElig;',
'barre_eo' => 'Insert an oe-ligature: &#339;',
'barre_eo_maj' => 'Insert a capital OE-ligature: &#338;',
'barre_euro' => 'Insert the &euro; symbol',
'barre_gestion_cr_changercassemajuscules' => 'Convert to UPPERCASE',
'barre_gestion_cr_changercasseminuscules' => 'Convert to lowercase',
'barre_gras' => '{{Bold}}',
'barre_guillemets' => 'Place between &laquo;double quotes&laquo;',
'barre_guillemets_simples' => 'Place between &ldquo;single quotes&ldquo;',
'barre_intertitre' => 'Turn into a {{{subheading}}}',
'barre_italic' => '{Italic}',
'barre_lien' => 'Turn into a [hyperlink->http://...]',
'barre_lien_input' => 'Please enter the target of your hyperlink (you may give an internet URL in the form http://www.mysite.com or else simply the number of an article on this site).',
'barre_note' => 'Turn into a [[Footnote]]',
'barre_paragraphe' => 'Create a paragraph',
'barre_quote' => '<quote>Quote a message</quote>',

// B (depuis BTv2)
'barre_langue' => 'Abbreviated lnguage', 
'barre_miseenevidence' => '[*Highlight*] the text',
'barre_exposant' => 'Put the text in &lt;sup&gt;superscript&lt;/sup&gt;',
'barre_petitescapitales' => 'Put the text in &lt;sc&gt;small capitales&lt;/sc&gt;',
'barre_centrer' => '[|Center|] the paragraph',
'barre_alignerdroite' => '[/Right align/] the paragraph',
'barre_encadrer' => '[(Frame)] the paragraph',
'barre_e_accent_grave' => 'Insert capital E grave',
'barre_ea' => 'Insert &aelig;',
'barre_ea_maj' => 'Insert &AElig;',
'barre_c_cedille_maj' => 'Insert capital C cedilla',

'barre_chercher' => 'Search & Replace',
'barre_tableau' => 'Insert/modify a table (select it first)',
'barre_glossaire' => '[?Glossary] reference (Wikipedia)',

'barre_caracteres' => 'Special characters',
'barre_adresse' => 'Address',
'barre_lien_externe' => 'External link',
'barre_bulle' => 'Help bubble',
'barre_formatages_speciaux' => 'Special formating',
'barre_galerie' => 'Open gallery',
'barre_gestion_caption' => 'Caption and Summary',
'barre_gestion_colonne' => 'No. of columns',
'barre_gestion_ligne' => 'No. of lines',
'barre_gestion_entete' => 'Header',
'barre_gestion_taille' => 'Fixed size',
'barre_gestion_cr_changercasse' => 'Change case',
'barre_gestion_cr_changercassemajuscules' => 'Convert to upper case',
'barre_gestion_cr_changercasseminuscules' => 'Convert to lower case',
'barre_gestion_cr_chercher' => 'Search',
'barre_gestion_cr_remplacer' => 'Replace',
'barre_gestion_cr_casse' => 'Match case',
'barre_gestion_cr_tout' => 'Replace all',
'barre_gestion_cr_entier' => 'Only complete words',
'barre_preview' => 'Preview mode',
'barre_stats' => 'Show text statistics',

'barre_code' => 'Edit a &lt;code&gt;computer code&lt;/code&gt;',
'barre_cadre' => 'Put in a &lt;cadre&gt;textarea&lt;/cadre&gt;',
'barre_poesie' => 'Edit as a &lt;poesie&gt;poetry&lt;/poesie&gt;',

'barre_ancres' => 'Anchors',
'barre_gestion_anc_caption' => 'Anchors',
'barre_gestion_anc_inserer' => 'Convert to anchor',
'barre_gestion_anc_nom' => 'Anchor name',
'barre_gestion_anc_pointer' => 'Point to an anchor',
'barre_gestion_anc_cible' => 'Anchor target',
'barre_gestion_anc_bulle' => 'Anchor help bubble',


);
?>

==> spip_2.1.1.orig.tar.gz: spip-2.1.1/extensions/porte_plume/lang/barre_outils_en.php <==
<?php
$GLOBALS[$GLOBALS['idx_lang']] = array(

// B Nouveautes 
'barre_clean' => 'Clean the code of all HTML tags',
'barre_lorem_ipsum' => 'Insert a fake paragraph',
'barre_lorem_ipsum_3' => 'Insert three fake paragraphs',
'barre_liste_ul' => 'Set list',
'barre_liste_ol' => 'Set numbered list',
'barre_indenter' => 'Indent a line',
'barre_desindenter' => 'Unindent a line',
'barre_inserer_caracteres' => 'Insert special characters',
'barre_barre' => 'Strike through the text',

'editer'=>'Edit',
'voir'=>'Preview',


// B (depuis SPIP)
'barre_a_accent_grave' => 'Insert a capital A with grave accent: &Agrave;',
'barre_aide' => 'Use the typographic short cuts to refine your layout',
'barre_c_cedille_maj' => 'Insert a capital &Ccedil; with cedilla: &Ccedil;',
'barre_e_accent_aigu' => 'Insert a capital E with acute accent: &Eacute;',
'barre_e_accent_grave' => 'Insert a capital E with grave accent: &Egrave;',
'barre_ea' => 'Insert an oe-ligature: &aelig;',
'barre_ea_maj' => 'Insert a capital an oe-ligature: &AElig;',
'barre_eo' => 'Insert an oe-ligature: &#339;',
'barre_eo_maj' => 'Insert a capital OE-ligature: &#338;',
'barre_euro' => 'Insert the &euro; symbol',
'barre_gestion_cr_changercassemajuscules' => 'Convert to UPPERCASE',
'barre_gestion_cr_changercasseminuscules' => 'Convert to lowercase',
'barre_gras' => '{{Bold}}',
'barre_guillemets' => 'Place between &laquo;double quotes&laquo;',
'barre_guillemets_simples' => 'Place between &ldquo;single quotes&ldquo;',
'barre_intertitre' => 'Turn into a {{{subheading}}}',
'barre_italic' => '{Italic}',
'barre_lien' => 'Turn into a [hyperlink->http://...]',
'barre_lien_input' => 'Please enter the target of your hyperlink (you may give an internet URL in the form http://www.mysite.com or else simply the number of an article on this site).',
'barre_note' => 'Turn into a [[Footnote]]',
'barre_paragraphe' => 'Create a paragraph',
'barre_quote' => '<quote>Quote a message</quote>',

// B (depuis BTv2)
'barre_langue' => 'Abbreviated lnguage', 
'barre_miseenevidence' => '[*Highlight*] the text',
'barre_exposant' => 'Put the text in &lt;sup&gt;superscript&lt;/sup&gt;',
'barre_petitescapitales' => 'Put the text in &lt;sc&gt;small capitales&lt;/sc&gt;',
'barre_centrer' => '[|Center|] the paragraph',
'barre_alignerdroite' => '[/Right align/] the paragraph',
'barre_encadrer' => '[(Frame)] the paragraph',
'barre_e_accent_grave' => 'Insert capital E grave',
'barre_ea' => 'Insert &aelig;',
'barre_ea_maj' => 'Insert &AElig;',
'barre_c_cedille_maj' => 'Insert capital C cedilla',

'barre_chercher' => 'Search & Replace',
'barre_tableau' => 'Insert/modify a table (select it first)',
'barre_glossaire' => '[?Glossary] reference (Wikipedia)',

'barre_caracteres' => 'Special characters',
'barre_adresse' => 'Address',
'barre_lien_externe' => 'External link',
'barre_bulle' => 'Help bubble',
'barre_formatages_speciaux' => 'Special formating',
'barre_galerie' => 'Open gallery',
'barre_gestion_caption' => 'Caption and Summary',
'barre_gestion_colonne' => 'No. of columns',
'barre_gestion_ligne' => 'No. of lines',
'barre_gestion_entete' => 'Header',
'barre_gestion_taille' => 'Fixed size',
'barre_gestion_cr_changercasse' => 'Change case',
'barre_gestion_cr_changercassemajuscules' => 'Convert to upper case',
'barre_gestion_cr_changercasseminuscules' => 'Convert to lower case',
'barre_gestion_cr_chercher' => 'Search',
'barre_gestion_cr_remplacer' => 'Replace',
'barre_gestion_cr_casse' => 'Match case',
'barre_gestion_cr_tout' => 'Replace all',
'barre_gestion_cr_entier' => 'Only complete words',
'barre_preview' => 'Preview mode',
'barre_stats' => 'Show text statistics',

'barre_code' => 'Edit a &lt;code&gt;computer code&lt;/code&gt;',
'barre_cadre' => 'Put in a &lt;cadre&gt;textarea&lt;/cadre&gt;',
'barre_poesie' => 'Edit as a &lt;poesie&gt;poetry&lt;/poesie&gt;',

'barre_ancres' => 'Anchors',
'barre_gestion_anc_caption' => 'Anchors',
'barre_gestion_anc_inserer' => 'Convert to anchor',
'barre_gestion_anc_nom' => 'Anchor name',
'barre_gestion_anc_pointer' => 'Point to an anchor',
'barre_gestion_anc_cible' => 'Anchor target',
'barre_gestion_anc_bulle' => 'Anchor help bubble',

// C
'config_info_enregistree' => "Configuration saved",

// E
'explication_barre_outils_public' => "CSS and Javascript Scripts for toolbars
	(Quill extension, Porte Plume) are loaded in the public site and 
	provide toolbars in forums, public crayons or other plugins
	if their respective configurations allow it.",
'explication_barre_outils_public_2' => "You can choose not to load
	these scripts in to lighten public pages.
	Therefore, whatever configuration the forums, crayons or plugins have, 
	no Quill toolbar will show automatically in the public site.",
	
// I
'info_porte_plume_titre' => "Toolbars configuration",
'info_barre_outils_public' => "Public toolbars",

// L
'label_barre_outils_public_oui' => "Load the toolbars\' scripts in the public site.",
'label_barre_outils_public_non' => "Do not load the toolbars\' scripts in the public site"

);
?>
